/*******************************************************************************
*
*            ATmega8 ADC Single Conversion with Interrupt
*            --------------------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   1. February 2013
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*
*   Clock source:           - Any 1MHz clock
*
*   Recommended             - High: 0xD9
*   Fuse settings:          - Low:  0xC1
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA16     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |              AREF |----
*          GND ---->|GND                |   |
*                   |                   |  ===
*          Vcc      |                   |   |
*           |       |                   |  GND
*           |       |                   |             
*          |P|      |                   |
*     10k  |O|      |                   |
*          |T|----->| PC0 (ADC4)        |             
*          |I|      |                   |
*           |       |                   |
*           |       |               PC0 |----> DOUT     
*          GND      |               PC1 |----> DOUT  
*                   |                   |  
*
*******************************************************************************/
#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{

    DDRB = 0x03;                      // Set PB0 and PB1 as output

    
    ADMUX = (1<<REFS0);               // Set Reference to AVCC and input to ADC0
    ADCSRA = (1<<ADEN)|(1<<ADPS2)     // Enable ADC, set prescaler to 16
            |(1<<ADIE);               // Fadc=Fcpu/prescaler=1000000/16=62.5kHz
                                      // Fadc should be between 50kHz and 200kHz
                                      // Enable ADC conversion complete interrupt

    sei();                            // Set the I-bit in SREG

    ADCSRA |= (1<<ADSC);              // Start the first conversion
    
    for(;;);                          // Endless loop
                                      // main() will never be left

    return 0;                         // This line will never be executed

}

// Interrupt subroutine for ADC conversion complete
ISR(ADC_vect) 
{
    PORTB^= 0x02;                     // Toggle PB1

    if(ADC > 512)                     // Is tht ADC vaue greater than 512?
        PORTB |= 0x01;                // Set PB0
    else                              // Is the ADC not greater than 512
       PORTB &= ~0x01;                // Reset PB0

    ADCSRA |= (1<<ADSC);          // Start the next conversion
} 





